==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/obj_form_generic.js <==
/*****************************************************
 * Extension script: Generic object extension for FORM objects
 * Supported objects: obj_input
 *                    obj_text
 *                    obj_button
 *                    obj_checkbox
 *                    onj_select
 *****************************************************/

_me = obj_form_generic.prototype;
function obj_form_generic(){};

	/**
	 * @brief: control html method "disabled" for current htmlform object
	 * @param: v - sets value property for
	 * @date : 16.4.2006 16:30:26
	 **/
	_me._value = function(v){
		if (typeof v != 'undefined'){
			this.__eIN.value = v;
			if(this.__restrictions && this.__restrictions.length) this.__check();
		}
		return this.__eIN.value;
	};

	/**
	 * @brief: control html property "disabled" for current htmlform object
	 * @param: b - boolean parametr
	 * @date: 16.4.2006 16:30:26
	 **/
	_me._disabled = function(b){
		if(b){
			this.__eIN.disabled = true;
        	addcss(this.__eIN,'disabled');
		}
		else{
        	this.__eIN.disabled = false;
        	removecss(this.__eIN,'disabled');
		}
	};

	_me._focus = function(){
		setTimeout('try{'+this._pathName+'.__eIN.focus();}catch(er){}',300);
	};

	_me._tabindex = function(i){
		this.__eIN.tabIndex = parseInt(i);
	};
	/**
	 * @brief: Updata method, keeps data synchronized
	 * @param: sDataSet - name of data set which is calling this method
	 * @date : 16.4.2006 16:30:26
	 **/
	_me.__update = function (sDataSet){
		if (!this._listener)
			this._listener = sDataSet;
		else
			if(sDataSet && this._listener != sDataSet) return;

		this._value(dataSet.get(this._listener,this._listenerPath));
	};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_form_generic.js <==
/*****************************************************
 * Extension script: Generic object extension for FORM objects
 * Supported objects: obj_input
 *                    obj_text
 *                    obj_button
 *                    obj_checkbox
 *                    onj_select
 *****************************************************/

_me = obj_form_generic.prototype;
function obj_form_generic(){};

	/**
	 * @brief: control html method "disabled" for current htmlform object
	 * @param: v - sets value property for
	 * @date : 16.4.2006 16:30:26
	 **/
	_me._value = function(v){
		if (typeof v != 'undefined'){
			this.__eIN.value = v;
			if(this.__restrictions && this.__restrictions.length) this.__check();
		}
		return this.__eIN.value.replace(/\r\n/g,"\n").replace(/\n/g,"\r\n");
	};

	/**
	 * @brief: control html property "disabled" for current htmlform object
	 * @param: b - boolean parametr
	 * @date: 16.4.2006 16:30:26
	 **/
	_me._disabled = function(b){
		if(typeof b == 'undefined')
			return this.__eIN.disabled;
		else
		if(b){
			this.__eIN.disabled = true;
			addcss(this.__eIN,'disabled');
		}
		else{
			this.__eIN.disabled = false;
			removecss(this.__eIN,'disabled');
		}
	};

	_me._focus = function(){
		setTimeout('try{'+this._pathName+'.__eIN.focus();}catch(er){}',300);
	};

	_me._tabindex = function(i){
		this.__eIN.tabIndex = parseInt(i);
	};
	/**
	 * @brief: Updata method, keeps data synchronized
	 * @param: sDataSet - name of data set which is calling this method
	 * @date : 16.4.2006 16:30:26
	 **/
	_me.__update = function (sDataSet){
		if (!this._listener)
			this._listener = sDataSet;
		else
			if(sDataSet && this._listener != sDataSet) return;

		this._value(dataSet.get(this._listener,this._listenerPath));
	};
